aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--internal/uevent/uevent.go8
1 files changed, 6 insertions, 2 deletions
diff --git a/internal/uevent/uevent.go b/internal/uevent/uevent.go
index a97423a8..6a3ff441 100644
--- a/internal/uevent/uevent.go
+++ b/internal/uevent/uevent.go
@@ -9,8 +9,12 @@ import (
"hakurei.app/internal/netlink"
)
-// Recoverable is satisfied by errors that are safe to recover from.
-type Recoverable interface{ recoverable() }
+type (
+ // Recoverable is satisfied by errors that are safe to recover from.
+ Recoverable interface{ recoverable() }
+ // Nontrivial is satisfied by errors preferring a JSON encoding.
+ Nontrivial interface{ nontrivial() }
+)
// Conn represents a NETLINK_KOBJECT_UEVENT socket.
type Conn struct{ conn *netlink.Conn }